
#ifndef __PREF_MAINWND_H__
#define __PREF_MAINWND_H__

#include "defs.h"

GtkWidget*      pref_mainwnd_start();
void            pref_mainwnd_end(gboolean save);

GtkWidget*      pref_font_start();
void            pref_font_end(gboolean save);

GtkWidget*      pref_color_start();
void            pref_color_end(gboolean save);

GtkWidget*      pref_mainwnd_search_start();
void            pref_mainwnd_search_end(gboolean save);

struct _pref_mainwnd
{
    GtkWidget   *bfont, *font, *wndpos;
    GtkWidget   *colors[COLOR_N];
    GtkWidget   *hits_auto, *hits, *word_hist;
} pref_mainwnd;

#endif /* __PREF_MAINWND_H__ */

